@@ -27,7 +27,7 @@ use XML::LibXML::XPathContext;
 use IO::Handle; # for FH reads called as methods
 
 BEGIN {
-$VERSION = "1.99"; # VERSION TEMPLATE: DO NOT CHANGE
+$VERSION = "2.0000"; # VERSION TEMPLATE: DO NOT CHANGE
 $ABI_VERSION = 2;
 require Exporter;
 require DynaLoader;
@@ -1526,31 +1526,13 @@ sub _isSameNodeLax {
 }
 
 {
-    # Note that we could generate a new hashref each time this
-    # is called. However, that breaks "each %$element" and
-    # "keys %$element". So instead we consistently return the
-    # same reference to the same (tied) hash. To do that, we
-    # need to use a fieldhash. Hash::FieldHash requires at least
-    # Perl 5.8, but XML-LibXML already dropped support for older
-    # Perls since XML-LibXML-1.77.
-    #
-    # If Hash::FieldHash isn't available we can sort of do the
-    # same thing by relying upon the stringification of non-scalar
-    # hash keys, and performing a bit of cleanup in DESTROY.
-    #
     my %tiecache;
-    BEGIN
+
+    sub __destroy_tiecache
     {
-        if (eval { require Hash::FieldHash; 1 })
-        {
-            Hash::FieldHash::fieldhashes(\%tiecache);
-            *__destroy_tiecache = sub {};
-        }
-        else
-        {
-            *__destroy_tiecache = sub { delete $tiecache{ 0+$_[0] } };
-        }
-    };
+        delete $tiecache{ 0+$_[0] };
+    }
+
     sub getAttributeHash
     {
         my $self = shift;
