@@ -1,6 +1,6 @@
 /**
  * perl-libxml-mm.c
- * $Id: perl-libxml-mm.c 785 2009-07-16 14:17:46Z pajas $
+ * $Id$
  *
  * This is free software, you may use it and distribute it under the same terms as
  * Perl itself.
@@ -928,7 +928,8 @@ PmmFastEncodeString( int charset,
     int i;
     /* first check that the input is not ascii */
     /* since we do not want to recode ascii as, say, UTF-16 */
-    if (len<0) len=xmlStrlen(string);
+    if (len == 0)
+        len=xmlStrlen(string);
     for (i=0; i<len; i++) {
         if(!string[i] || string[i] & 0x80) {
             break;
